@@ -6,21 +6,25 @@
 
 const char* FILE_NAME = "Sys/IO/FileStream.c";
 
-static const int FILE_STREAM_CLOSED_INDEX = 0;
-
 int32_t SPVM__Sys__IO__FileStream__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 
+  int32_t e = 0;
+  
   // File handle
   void* obj_self = stack[0].oval;
   
-  int32_t file_stream_is_closed = env->get_pointer_field_int(env, stack, obj_self, FILE_STREAM_CLOSED_INDEX);
+  int32_t closed = env->get_field_byte_by_name(env, stack, obj_self, "closed", &e, FILE_NAME, __LINE__);
+  if (e) { return e; }
   
   FILE* fh = (FILE*)env->get_pointer(env, stack, obj_self);
   
   assert(fh);
+
+  int32_t no_need_free = env->get_field_byte_by_name(env, stack, obj_self, "no_need_free", &e, FILE_NAME, __LINE__);
+  if (e) { return e; }
   
-  if (!env->get_pointer_no_need_free(env, stack, obj_self)) {
-    if (!file_stream_is_closed) {
+  if (!no_need_free) {
+    if (!closed) {
       int32_t status = fclose(fh);
       if (status == EOF) {
         env->die(env, stack, "[System Error]fclose failed:%s.", env->strerror(env, stack, errno, 0), FILE_NAME, __LINE__);
